@@ -17,7 +17,7 @@ import requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import AssetsMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
-from ibm_watson_machine_learning.wml_client_error import  WMLClientError
+from ibm_watson_machine_learning.wml_client_error import  WMLClientError, CannotSetProjectOrSpace
 from ibm_watson_machine_learning.instance_new_plan import ServiceInstanceNewPlan
 
 
@@ -71,11 +71,11 @@ class Set(WMLResource):
 
         if space_details.status_code == 404:
             error_msg = "Space with id '{}' does not exist".format(space_uid)
-            raise WMLClientError(error_msg)
-            return "FAILURE"
+            raise CannotSetProjectOrSpace(reason=error_msg)
+
         elif space_details.status_code == 200:
             self._client.default_space_id = space_uid
-            if  self._client.default_project_id is not None:
+            if self._client.default_project_id is not None:
                 print("Unsetting the project_id ...")
             self._client.default_project_id = None
 
@@ -95,9 +95,7 @@ class Set(WMLResource):
 
             return "SUCCESS"
         else:
-            print("Failed to set space.")
-            print(space_details.text)
-            return "FAILURE"
+            raise CannotSetProjectOrSpace(reason=space_details.text)
 
 
     ##Setting project ID
@@ -139,9 +137,7 @@ class Set(WMLResource):
                 project_endpoint = self._client.service_instance._href_definitions.get_project_href(project_id)
                 project_details = requests.get(project_endpoint, headers=self._client._get_headers(), verify=False)
                 if project_details.status_code != 200 and project_details.status_code != 204:
-                    print("Failed to set Project: " + project_details.text)
-                    self._client.default_project_id = None
-                    return "FAILURE"
+                    raise CannotSetProjectOrSpace(reason=project_details.text)
                 else:
                     self._client.project_type = project_details.json()['entity']['storage']['type']
                     if self._client.CLOUD_PLATFORM_SPACES:
