@@ -86,9 +86,9 @@ class Deployments(WMLResource):
     def create(self, artifact_uid=None, meta_props=None, rev_id=None, **kwargs):
             """
                 Create a deployment from an artifact. As artifact we understand model or function which may be deployed.
-                
+
                 **Parameters**
-                
+
                 .. important::
 
                     #. **artifact_uid**:  Published artifact UID (model or function uid)\n
@@ -98,9 +98,9 @@ class Deployments(WMLResource):
                                        >>> client.deployments.ConfigurationMetaNames.get()
 
                        **type**: dict\n
-                
+
                 **Output**
-                
+
                 .. important::
 
                     **returns**: metadata of the created deployment\n
@@ -134,6 +134,10 @@ class Deployments(WMLResource):
 
             metaProps = self.ConfigurationMetaNames._generate_resource_metadata(meta_props)
 
+            if 'serving_name' in str(metaProps) and 'r_shiny' in str(metaProps):
+                metaProps['serving_name'] = meta_props['serving_name']
+                del metaProps['online']
+
             if (self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and 'wml_instance_id' in meta_props:
                 metaProps.update({'wml_instance_id': meta_props['wml_instance_id']})
 
@@ -276,21 +280,21 @@ class Deployments(WMLResource):
     def get_uid(deployment_details):
         """
             Get deployment_uid from deployment details. Deprecated!! Use get_id(deployment_details) instead
-            
+
             **Parameters**
-            
+
             .. important::
                 #. **deployment_details**:  Metadata of the deployment\n
                    **type**: dict\n
-            
+
             **Output**
-            
+
             .. important::
                 **returns**: deployment UID that is used to manage the deployment\n
                 **return type**: str
-            
+
             **Example**
-            
+
              >>> deployment_uid = client.deployments.get_uid(deployment)
         """
         Deployments._validate_type(deployment_details, u'deployment_details', dict, True)
@@ -341,21 +345,21 @@ class Deployments(WMLResource):
     def get_href(deployment_details):
         """
             Get deployment_href from deployment details.
-            
+
             **Parameters**
-            
+
             .. important::
                 #. **deployment_details**:  Metadata of the deployment.\n
                    **type**: dict\n
-            
+
             **Output**
-            
+
             .. important::
                 **returns**: Deployment href that is used to manage the deployment.\n
                 **return type**: str
-            
+
             **Example**
-            
+
             >>> deployment_href = client.deployments.get_href(deployment)
 
         """
@@ -377,12 +381,12 @@ class Deployments(WMLResource):
         return url
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, deployment_uid=None, serving_name=None, limit=None):
+    def get_details(self, deployment_uid=None, serving_name=None, limit=None, asynchronous=False, get_all=False):
         """
            Get information about your deployment(s). If deployment_uid is not passed, all deployment details are fetched.
-           
+
            **Parameters**
-           
+
            .. important::
                 #. **deployment_uid**: Unique Id of Deployment (optional)\n
                    **type**: str\n
@@ -390,9 +394,13 @@ class Deployments(WMLResource):
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
-           
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
+
            **Output**
-           
+
            .. important::
                 **returns**: metadata of deployment(s)\n
                 **return type**: dict\n
@@ -401,12 +409,17 @@ class Deployments(WMLResource):
            .. note::
                 If deployment_uid is not specified, all deployments metadata is fetched (can be filtered with serving_name)\n
 
-           
+
            **Example**
-           
+
             >>> deployment_details = client.deployments.get_details(deployment_uid)
             >>> deployment_details = client.deployments.get_details(deployment_uid=deployment_uid)
             >>> deployments_details = client.deployments.get_details()
+            >>> deployments_details = client.deployments.get_details(limit=100)
+            >>> deployments_details = client.deployments.get_details(limit=100, get_all=True)
+            >>> deployments_details = []
+            >>> for entry in client.deployments.get_details(limit=100, asynchronous=True, get_all=True):
+            >>>    deployments_details.extend(entry)
 
         """
         ##To be removed once deployments adds support for deployments
@@ -438,39 +451,49 @@ class Deployments(WMLResource):
                     )
                 return self._handle_response(200, "deployment", response)
             else:
-                deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments')
-                if "system" in deployment_details:
-                    print("Note: " + deployment_details['system']['warnings'][0]['message'])
-                return deployment_details
+
+                if asynchronous:
+                    return self._get_artifact_details(url, deployment_uid, limit, 'deployments',
+                                                      _async=asynchronous, _all=get_all)
+
+                else:
+                    deployment_details = self._get_artifact_details(url, deployment_uid, limit, 'deployments',
+                                                                    _async=asynchronous, _all=get_all)
+                    if "system" in deployment_details:
+                        print("Note: " + deployment_details['system']['warnings'][0]['message'])
+                    return deployment_details
         else:
             query_params = self._client._params()
             if serving_name:
                 query_params['serving_name'] = serving_name
 
-            details = self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params)
-            
-            return details
+            if deployment_uid is None:
+                return self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params,
+                                                  _async=asynchronous, _all=get_all)
+
+            else:
+                return self._get_artifact_details(url, deployment_uid, limit, 'deployments', query_params=query_params)
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_scoring_href(deployment_details):
         """
             Get scoring url from deployment details.
-            
+
             **Parameters**
-            
+
             .. important::
                 #. **deployment_details**:  Metadata of the deployment\n
                    **type**: dict\n
-            
+
             **Output**
-            
+
             .. important::
                 **returns**: scoring endpoint url that is used for making scoring requests\n
                 **return type**: str\n
-            
+
             **Example**
-            
+
              >>> scoring_href = client.deployments.get_scoring_href(deployment)
 
         """
@@ -542,21 +565,21 @@ class Deployments(WMLResource):
     def delete(self, deployment_uid):
         """
             Delete deployment.
-            
+
             **Parameters**
-            
+
             .. important::
                 #. **deployment uid**:  Unique Id of  Deployment\n
                    **type**: str\n
-            
+
             **Output**
-            
+
             .. important::
                 **returns**: status ("SUCCESS" or "FAILED")\n
                 **return type**: str\n
-            
+
             **Example**
-            
+
              >>> client.deployments.delete(deployment_uid)
 
         """
@@ -802,11 +825,11 @@ class Deployments(WMLResource):
         details = self.get_details(virtual_deployment_uid)
         download_url = self.get_download_url(details)
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
-            download_url = download_url + "&version=2021-06-24"
+            download_url = download_url + "&version=" + self._client.version_param
             params = None
         if not self._ICP:
             # if self._client.CLOUD_PLATFORM_SPACES:
-            #     download_url = download_url + "&version=2021-06-24"
+            #     download_url = download_url + "&version=" + self._client.version_param
             #     response = requests.get(
             #         download_url,
             #         headers=self._client._get_headers()
@@ -907,21 +930,21 @@ class Deployments(WMLResource):
     def list(self, limit=None):
         """
            List deployments. If limit is set to None there will be only first 50 records shown.
-           
+
            **Parameters**
-           
+
            .. important::
                 #. **limit**:  limit number of fetched records\n
                    **type**: int\n
-           
+
            **Output**
-           
+
            .. important::
                 This method only prints the list of all deployments in a table format.\n
                 **return type**: None\n
 
            **Example**
-           
+
             >>> client.deployments.list()
 
         """
@@ -1028,9 +1051,9 @@ class Deployments(WMLResource):
         """
                 Updates existing deployment metadata. If ASSET is patched, then 'id' field is mandatory and
                 it starts a deployment with the provided asset id/rev. Deployment id remains same
-                
+
                 **Parameters**
-                
+
                 .. important::
 
                     #. **deployment_uid**: Unique Id of deployment which  should be updated\n
@@ -1039,14 +1062,14 @@ class Deployments(WMLResource):
                        **type**: dict\n
 
                 **Output**
-                
+
                 .. important::
 
                     **returns**: metadata of updated deployment\n
                     **return type**: dict\n
-                    
+
                 **Example**
-                
+
                  >>> metadata = {
                  >>> client.deployments.ConfigurationMetaNames.NAME:"updated_Deployment",
                  >>> client.deployments.ConfigurationMetaNames.ASSET: { "id": "ca0cd864-4582-4732-b365-3165598dc945", "rev":"2" }
