@@ -19,7 +19,7 @@ from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.enums import (
     TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, ForecastingAlgorithms, PredictionType, Metrics,\
     Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass, ClassificationAlgorithmsCP4D,
-    RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D)
+    RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D, SamplingTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
     NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario, \
     TSNotSupported, ParamOutOfRange
@@ -172,6 +172,8 @@ class AutoAI(BaseExperiment):
                   text_processing: bool = None,
                   word2vec_feature_number: int = None,
                   daub_give_priority_to_runtime: float = None,
+                  # sampling_type: 'SamplingTypes' = None, #TODO: Uncomment to add sampling_type support
+                  n_parallel_data_connections: int =None,
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
@@ -283,6 +285,10 @@ class AutoAI(BaseExperiment):
             If set to 0.0 only score is used. If set to 1 equally score and runtime are used.
             If set to value higher than 1 the runtime gets higher importance over score.
 
+        n_parallel_data_connections: int, optional
+            Number of maximum parallel connection to data source.
+            Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
+
         Returns
         -------
         RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object.
@@ -334,6 +340,12 @@ class AutoAI(BaseExperiment):
         # >>>    }
         # """
 
+        # TODO: Pass the sampling_type doc description, when adding support for that
+        # sampling_type: str, optional
+        #     Type of sampling data for training. One of SamplingTypes enum values.
+        #     Default is SamplingTypes.FIRST_N_RECORDS.
+        #     Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
+
         if prediction_type == PredictionType.FORECASTING and self._workspace.wml_client.ICP and \
                 (self._workspace.wml_client.wml_credentials['version'].startswith('2.5') or \
                         self._workspace.wml_client.wml_credentials['version'].startswith('3.0') or \
@@ -465,6 +477,8 @@ class AutoAI(BaseExperiment):
                 autoai_pod_version=kwargs.get('autoai_pod_version', None),
                 obm_pod_version=kwargs.get('obm_pod_version', None),
                 # fairness_info=fairness_info, #TODO: Uncomment to add fairness support
+                # sampling_type=sampling_type, #TODO: Uncomment to add sampling_type support
+                n_parallel_data_connections=n_parallel_data_connections,
                 **reduced_kwargs
             )
             optimizer._workspace = self._workspace
