@@ -67,7 +67,7 @@ class WMLEngine(BaseEngine):
         self._current_run_id = None
         self._20_class_limit_removal_test = False
 
-    def _initialize_wml_pipeline_metadata(self) -> None:
+    def _initialize_wml_pipeline_metadata(self, **kwargs) -> None:
         """
         Initialization of WML Pipeline Document (WML client Meta Parameter) with provided parameters and default ones.
         """
@@ -118,6 +118,11 @@ class WMLEngine(BaseEngine):
             }
         }
 
+        if kwargs.get('enable_all_data_sources') is not None:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['enable_all_data_sources'
+            ] = kwargs['enable_all_data_sources']
+
         # Text transformer params
         if not self._wml_client.ICP_30 and not self._wml_client.ICP_35:
             if self._auto_pipelines_parameters.get('text_processing') is not None:
@@ -340,7 +345,7 @@ class WMLEngine(BaseEngine):
                                            "wml_data": {
                                                "hardware_spec": {
                                                    "name": "M-Spark",
-                                                   "num_nodes": 1
+                                                   "num_nodes": self._auto_pipelines_parameters['data_join_graph'].worker_nodes_number
                                                }
                                            }
                                        }
@@ -362,7 +367,7 @@ class WMLEngine(BaseEngine):
             else:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['engine'][
-                    'template_id'] = 'spark-2.4.0-automl-icp4d-template'
+                    'template_id'] = 'spark-3.0.0-automl-cp4d-template'
         # --- end note
 
     def _initialize_wml_training_metadata(self,
@@ -428,7 +433,9 @@ class WMLEngine(BaseEngine):
             AutoAi experiment parameters.
         """
         self._auto_pipelines_parameters = params
-        self._initialize_wml_pipeline_metadata()
+        self._initialize_wml_pipeline_metadata(**kwargs)
+        if 'enable_all_data_sources' in kwargs:
+            del kwargs['enable_all_data_sources']
         self._wml_stored_pipeline_details = self._wml_client.pipelines.store(meta_props=self._wml_pipeline_metadata, **kwargs)
 
     def get_params(self) -> dict:
@@ -719,6 +726,8 @@ class WMLEngine(BaseEngine):
                     raise InvalidPredictionType(self._auto_pipelines_parameters['prediction_type'],
                                                 reason="Prediction type not recognized.")
 
+                break
+
         # --- end note
 
         return pipeline_parameters
