@@ -728,7 +728,7 @@ score = {}()
         response_delete
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, function_uid=None, limit=None):
+    def get_details(self, function_uid=None, limit=None, asynchronous=False, get_all=False):
         """
             Get metadata of function(s). If no function UID is specified all functions metadata is returned.
 
@@ -739,6 +739,10 @@ score = {}()
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -754,6 +758,11 @@ score = {}()
 
              >>> function_details = client._functions.get_details(function_uid)
              >>> function_details = client._functions.get_details()
+             >>> function_details = client._functions.get_details(limit=100)
+             >>> function_details = client._functions.get_details(limit=100, get_all=True)
+             >>> function_details = []
+             >>> for entry in client._functions.get_details(limit=100, asynchronous=True, get_all=True):
+             >>>    function_details.extend(entry)
          """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -767,7 +776,11 @@ score = {}()
         else:
             url = self._client.service_instance._href_definitions.get_functions_href()
 
-        return self._get_artifact_details(url, function_uid, limit, 'functions')
+        if function_uid is None:
+            return self._get_artifact_details(url, function_uid, limit, 'functions', _async=asynchronous, _all=get_all)
+
+        else:
+            return self._get_artifact_details(url, function_uid, limit, 'functions')
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
