@@ -25,7 +25,7 @@ from typing import Union, Tuple, TYPE_CHECKING
 from warnings import warn
 
 import requests
-from pandas import concat, DataFrame
+from pandas import concat, DataFrame, read_csv
 
 from ibm_watson_machine_learning.utils.autoai.utils import try_load_dataset, try_load_tar_gz
 from ibm_watson_machine_learning.utils.autoai.enums import DataConnectionTypes
@@ -164,7 +164,7 @@ class BaseDataConnection(ABC):
                 buffer = io.BytesIO(downloaded_asset)
                 json_content = json.loads(buffer.getvalue().decode('utf-8'))
 
-        elif self.type == DataConnectionTypes.CA:
+        elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
             if self._check_if_connection_asset_is_s3():
                 cos_client = self._init_cos_client()
 
@@ -311,16 +311,32 @@ class BaseDataConnection(ABC):
 
                 if self.connection is None:
                     from .connections import S3Connection
-                    self.connection = S3Connection(
-                        endpoint_url=connection_details['entity']['properties'].get('url'),
-                        access_key_id=connection_details['entity']['properties'].get('access_key'),
-                        secret_access_key=connection_details['entity']['properties'].get('secret_key')
-                    )
+                    if ('api_key' in str(connection_details['entity']['properties']) and
+                            'iam_url' in str(connection_details['entity']['properties'])):
+                        self.connection = S3Connection(
+                            api_key=connection_details['entity']['properties'].get('api_key'),
+                            auth_endpoint=connection_details['entity']['properties'].get('iam_url'),
+                            endpoint_url=connection_details['entity']['properties'].get('url')
+                        )
+
+                    else:
+                        self.connection = S3Connection(
+                            endpoint_url=connection_details['entity']['properties'].get('url'),
+                            access_key_id=connection_details['entity']['properties'].get('access_key'),
+                            secret_access_key=connection_details['entity']['properties'].get('secret_key')
+                        )
 
                 else:
-                    self.connection.secret_access_key = connection_details['entity']['properties'].get('secret_key')
-                    self.connection.access_key_id = connection_details['entity']['properties'].get('access_key')
-                    self.connection.endpoint_url = connection_details['entity']['properties'].get('url')
+                    if ('api_key' in str(connection_details['entity']['properties']) and
+                            'iam_url' in str(connection_details['entity']['properties'])):
+                        self.connection.api_key = connection_details['entity']['properties'].get('api_key')
+                        self.connection.auth_endpoint = connection_details['entity']['properties'].get('iam_url')
+                        self.connection.endpoint_url = connection_details['entity']['properties'].get('url')
+
+                    else:
+                        self.connection.secret_access_key = connection_details['entity']['properties'].get('secret_key')
+                        self.connection.access_key_id = connection_details['entity']['properties'].get('access_key')
+                        self.connection.endpoint_url = connection_details['entity']['properties'].get('url')
 
                 if self.type == 'container':
                     self.location.bucket = connection_details['entity']['properties']['bucket_name']
@@ -357,10 +373,20 @@ class BaseDataConnection(ABC):
                 Prefix=location_path))[0].get()
 
         buffer = io.BytesIO(file['Body'].read())
-        data = try_load_tar_gz(buffer=buffer,
-                               separator=self.auto_pipeline_params.get('csv_separator', ','),
-                               encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
-                               )
+
+        if '.csv' in location_path:
+            file_name = 'indices.csv'
+            with open(file_name, 'wb') as out:
+                out.write(buffer.read())
+
+            data = read_csv(file_name, sep=self.auto_pipeline_params.get('csv_separator', ','),
+                            encoding=self.auto_pipeline_params.get('encoding', 'utf-8'))
+
+        else:
+            data = try_load_tar_gz(buffer=buffer,
+                                   separator=self.auto_pipeline_params.get('csv_separator', ','),
+                                   encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
+                                   )
 
         return data
 
@@ -414,25 +440,29 @@ class BaseDataConnection(ABC):
                     verify=False)
 
             if response.status_code == 200:
-                attachment_details = response.json()
-                if "url" in attachment_details:
-                    file_asset_url = attachment_details['url']
-                    csv_response = requests.get(file_asset_url, verify=False)
+                try:
+                    attachment_details = response.json()
+                    if "url" in attachment_details:
+                        file_asset_url = attachment_details['url']
+                        csv_response = requests.get(file_asset_url, verify=False)
 
-                    if csv_response.status_code != 200:
-                        raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
+                        if csv_response.status_code != 200:
+                            raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
 
-                    downloaded_asset = csv_response.content
+                        downloaded_asset = csv_response.content
 
-                    # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
-                    buffer = io.BytesIO(downloaded_asset)
-                    data = try_load_dataset(buffer=buffer,
-                                            sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
-                                            separator=self.auto_pipeline_params.get('csv_separator', ','),
-                                            encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
-                                            )
+                        # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
+                        buffer = io.BytesIO(downloaded_asset)
+                        data = try_load_dataset(buffer=buffer,
+                                                sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
+                                                separator=self.auto_pipeline_params.get('csv_separator', ','),
+                                                encoding=self.auto_pipeline_params.get('encoding', 'utf-8')
+                                                )
 
-                    return data
+                        return data
+
+                except requests.exceptions.MissingSchema:
+                    pass  # go to 'handle' part and check if we are able to download data asset from WS
 
             # note: read the csv url
             if 'handle' in asset_details['attachments'][0]:
@@ -659,7 +689,6 @@ class BaseDataConnection(ABC):
 
         return data
 
-
     def _create_conn_details_for_container(self) -> dict:
         if self._wml_client is not None:
             if self._wml_client.default_space_id is not None:
@@ -739,4 +768,4 @@ class BaseDataConnection(ABC):
             except ModuleNotFoundError:
                 raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
 
-        return connection_details
\ No newline at end of file
+        return connection_details
