@@ -359,14 +359,21 @@ class DataConnection(BaseDataConnection):
 
         return data_connection
 
-    def read_indices(self, **kwargs):
+    def read_indices(self, indices_location: str = None, **kwargs):
         training_details = self._wml_client.training.get_details(self.auto_pipeline_params['run_id'])
         # TODO indices location should be read from response, than constructed
-        # holdout_data_indices_location = training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['holdout_data_indices_location']
-        holdout_data_indices_location = \
-        training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['schema_location']
-        holdout_data_indices_location = '/'.join(
-            holdout_data_indices_location.split('/')[:-3]) + '/holdout_data_indices.tar.gz'
+        if indices_location is not None:    # when location is provided from metadata
+            holdout_data_indices_location = indices_location
+
+        else:
+            try:
+                holdout_data_indices_location = training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['holdout_data_indices_location']
+
+            except KeyError:
+                holdout_data_indices_location = \
+                training_details['entity']['status']['metrics'][0]['context']['intermediate_model']['schema_location']
+                holdout_data_indices_location = '/'.join(
+                    holdout_data_indices_location.split('/')[:-3]) + '/holdout_data_indices.tar.gz'
 
         data = DataFrame()
 
@@ -502,7 +509,9 @@ class DataConnection(BaseDataConnection):
         indices = None
         if with_holdout_split:
             try:
-                indices = self.read_indices()
+                indices = self.read_indices(
+                    indices_location=experiment_metadata.get('holdout_data_indices_location'))
+
             except Exception as e:
                 print("\"with_holdout_split\" option is deprecated.")
                 warn("\"with_holdout_split\" option is deprecated.")
@@ -565,10 +574,12 @@ class DataConnection(BaseDataConnection):
                 raise e
 
             except Exception as e:
-                # do not try Flight is we are on the cloud
-                if (self._wml_client is not None and not self._wml_client.ICP) or (
-                    os.environ.get('USER_ACCESS_TOKEN') is None
-                ):
+                # do not try Flight if we are on the cloud
+                if self._wml_client is not None:
+                    if not self._wml_client.ICP:
+                        raise e
+
+                elif os.environ.get('USER_ACCESS_TOKEN') is None:
                     raise e
 
                 data_location = self.location.to_dict()
@@ -593,44 +604,46 @@ class DataConnection(BaseDataConnection):
                 data = self._download_training_data_from_file_system()
 
         elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
-            with all_logging_disabled():
-                if self._check_if_connection_asset_is_s3():
-                    cos_client = self._init_cos_client()
+            try:
+                with all_logging_disabled():
+                    if self._check_if_connection_asset_is_s3():
+                        cos_client = self._init_cos_client()
 
-                    try:
-                        if self._obm:
-                            data = self._download_obm_data_from_cos(cos_client=cos_client)
+                        try:
+                            if self._obm:
+                                data = self._download_obm_data_from_cos(cos_client=cos_client)
 
-                        else:
-                            data = self._download_data_from_cos(cos_client=cos_client)
+                            else:
+                                data = self._download_data_from_cos(cos_client=cos_client)
 
-                    except Exception as cos_access_exception:
-                        raise ConnectionError(
-                            f"Unable to access data object in cloud object storage with credentials supplied. "
-                            f"Error: {cos_access_exception}")
-                else:
-                    try:
+                        except Exception as cos_access_exception:
+                            raise ConnectionError(
+                                f"Unable to access data object in cloud object storage with credentials supplied. "
+                                f"Error: {cos_access_exception}")
+                    else:
                         data = self._download_data_from_nfs_connection()
 
-                    except Exception as e:
-                        # do not try Flight is we are on the cloud
-                        if (self._wml_client is not None and not self._wml_client.ICP) or (
-                            os.environ.get('USER_ACCESS_TOKEN') is None
-                        ):
-                            raise e
+            except Exception as e:
+                # do not try Flight is we are on the cloud
+                if self._wml_client is not None:
+                    if not self._wml_client.ICP:
+                        raise e
 
-                        try_import_pyarrow()
+                elif os.environ.get('USER_ACCESS_TOKEN') is None:
+                    raise e
 
-                        flight_service = FlightService(
-                            wml_client=self._wml_client,
-                            params=self.auto_pipeline_params,
-                            data_location={'location': self.location.to_dict(),
-                                           'type': self.type,
-                                           "connection": self.connection.to_dict()},
-                            experiment_metadata=kwargs.get('experiment_metadata')
-                        )
+                try_import_pyarrow()
 
-                        data = flight_service.read()
+                flight_service = FlightService(
+                    wml_client=self._wml_client,
+                    params=self.auto_pipeline_params,
+                    data_location={'location': self.location.to_dict(),
+                                   'type': self.type,
+                                   "connection": self.connection.to_dict()},
+                    experiment_metadata=kwargs.get('experiment_metadata')
+                )
+
+                data = flight_service.read()
 
         if isinstance(data, DataFrame) and 'Unnamed: 0' in data.columns.tolist():
             data.drop(['Unnamed: 0'], axis=1, inplace=True)
@@ -901,7 +914,7 @@ class ContainerLocation(BaseLocation):
 
     def __init__(self, path: Optional[str] = None, **kwargs) -> None:
         if path is None:
-            self.path = "/{option}/{id}" + f"/assets/auto_ml/auto_ml.{uuid.uuid4()}/wml_data"
+            self.path = "default_autoai_out"
 
         else:
             self.path = path
