@@ -167,6 +167,10 @@ DATAPLATFORM_URLS_MAP = {
             'https://us-south.ml.cloud.ibm.com': 'https://dataplatform.cloud.ibm.com'
         }
 
+WKC_MODEL_REGISTER = u"{}/v1/aigov/model_inventory/models/{}/model_entry"
+WKC_MODEL_LIST_FROM_CATALOG = u"{}/v1/aigov/model_inventory/{}/model_entries"
+WKC_MODEL_LIST_ALL = u"{}/v1/aigov/model_inventory/model_entries"
+
 def is_url(s):
     res = re.match('https?:\/\/.+', s)
     return res is not None
@@ -504,6 +508,19 @@ class HrefDefinitions:
             finally:
                 return promote_href
 
+    def get_wkc_model_register_href(self, model_id) -> str:
+        return WKC_MODEL_REGISTER.format(self._get_platform_url_if_exists(), model_id)
+
+    def get_wkc_model_list_from_catalog_href(self, catalog_id) -> str:
+        return WKC_MODEL_LIST_FROM_CATALOG.format(self._get_platform_url_if_exists(), catalog_id)
+
+    def get_wkc_model_list_all_href(self) -> str:
+        return WKC_MODEL_LIST_ALL.format(self._get_platform_url_if_exists())
+
+    def get_wkc_model_delete_href(self, asset_id) -> str:
+        return WKC_MODEL_REGISTER.format(self._get_platform_url_if_exists(), asset_id)
+
+
     # def get_envs_href(self):
     #     return DEPLOYMENT_ENVS_HREF_PATTERN.format(self._wml_credentials['url'])
     #
