@@ -258,7 +258,7 @@ class Import(WMLResource):
             print("Import job deleted")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, import_id=None, space_id=None, project_id=None, limit=None):
+    def get_details(self, import_id=None, space_id=None, project_id=None, limit=None, asynchronous=False, get_all=False):
         """
             Get metadata of the given import job. if no import_id is specified, all
             imports metadata is returned.
@@ -274,6 +274,10 @@ class Import(WMLResource):
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -289,6 +293,11 @@ class Import(WMLResource):
 
              >>> details = client.import_assets.get_details(import_id)
              >>> details = client.import_assets.get_details()
+             >>> details = client.import_assets.get_details(limit=100)
+             >>> details = client.import_assets.get_details(limit=100, get_all=True)
+             >>> details = []
+             >>> for entry in client.import_assets.get_details(limit=100, asynchronous=True, get_all=True):
+             >>>    details.extend(entry)
          """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
@@ -311,7 +320,12 @@ class Import(WMLResource):
         else:
             params.update({"project_id": project_id})
 
-        return self._get_artifact_details(href, import_id, limit, 'import job', query_params=params)
+        if import_id is None:
+            return self._get_artifact_details(href, import_id, limit, 'import job', query_params=params,
+                                              _async=asynchronous, _all=get_all)
+
+        else:
+            return self._get_artifact_details(href, import_id, limit, 'import job', query_params=params)
     
     def list(self, space_id=None, project_id=None, limit=None):
         """
