@@ -188,7 +188,7 @@ class FunctionCollection:
                 function_input = self._prepare_function_input(artifact)
                 r = self.repository_api.repository_new_function(function_input)
                 statuscode = r[1]
-                if statuscode is not 201:
+                if statuscode != 201:
                     logger.info('Error while creating function: no location header')
                     raise ApiException(404, 'No artifact location')
 
@@ -237,7 +237,7 @@ class FunctionCollection:
         function_patch_output = self.repository_api.repository_patch_functions_with_http_info(function_id, function_patch_input, revision_id)
         statuscode = function_patch_output[1]
 
-        if statuscode is not 200:
+        if statuscode != 200:
             logger.info('Error while patching function: no location header')
             raise ApiException(statuscode,"Error while patching function")
 
