@@ -420,7 +420,7 @@ class ModelDefinition(WMLResource):
 
             **Example**
 
-             >>> client.script.download(asset_uid,"script_file.zip")
+             >>> client.model_definitions.download(model_definition_uid, "model_definition_file")
         """
 
         self._client._check_if_either_is_set()
