@@ -423,7 +423,7 @@ class Pipelines(WMLResource):
         return self._handle_response(204, u'pipeline deletion', response_delete, False)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, pipeline_uid=None, limit=None):
+    def get_details(self, pipeline_uid=None, limit=None, asynchronous=False, get_all=False):
         """
            Get metadata of stored pipeline(s). If pipeline UID is not specified returns all pipelines metadata.
 
@@ -434,6 +434,10 @@ class Pipelines(WMLResource):
                    **type**: str\n
                 #. **limit**:  limit number of fetched records (optional)\n
                    **type**: int\n
+                #. **asynchronous**:  if True, it will work as a generator (optional)\n
+                   **type**: bool\n
+                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
+                   **type**: bool\n
 
            **Output**
 
@@ -449,6 +453,11 @@ class Pipelines(WMLResource):
 
             >>> pipeline_details = client.pipelines.get_details(pipeline_uid)
             >>> pipeline_details = client.pipelines.get_details()
+            >>> pipeline_details = client.pipelines.get_details(limit=100)
+            >>> pipeline_details = client.pipelines.get_details(limit=100, get_all=True)
+            >>> pipeline_details = []
+            >>> for entry in client.pipelines.get_details(limit=100, asynchronous=True, get_all=True):
+            >>>    pipeline_details.extend(entry)
 
         """
         ##For CP4D, check if either spce or project ID is set
@@ -464,7 +473,11 @@ class Pipelines(WMLResource):
         else:
             url = self._client.service_instance._href_definitions.get_pipelines_href()
 
-        return self._get_artifact_details(url, pipeline_uid, limit, 'definitions',summary="False")
+        if pipeline_uid is None:
+            return self._get_artifact_details(url, pipeline_uid, limit, 'definitions', summary="False",
+                                              _async=asynchronous, _all=get_all)
+        else:
+            return self._get_artifact_details(url, pipeline_uid, limit, 'definitions',summary="False")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_revision_details(self, pipeline_uid, rev_uid):
