@@ -193,10 +193,12 @@ class DataJoinGraph(Digraph, BaseOBMJson):
     def __init__(self,
                  t_shirt_size: 'TShirtSize' = TShirtSize.M,
                  max_depth: int = 3,
-                 data_source_type: str = "csv"):
+                 data_source_type: str = "csv",
+                 worker_nodes_number: int = 1):
         super().__init__(comment='Data Join Graph')
 
         self.t_shirt_size = t_shirt_size
+        self.worker_nodes_number = worker_nodes_number
 
         # note: these values should be provided by optimizer
         self.target_column = None
