@@ -17,7 +17,7 @@ import requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import ScriptMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
-from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
+from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure, ForbiddenActionForGitBasedProject
 import os
 
 _DEFAULT_LIST_LENGTH = 50
@@ -124,6 +124,9 @@ class Script(WMLResource):
                  >>> asset_details = client.scripts.store(meta_props=metadata,file_path="/path/to/file")
 
         """
+        if self._client.project_type == 'local_git_storage':
+            raise ForbiddenActionForGitBasedProject(reason="Storing Scripts is not supported for git based project.")
+
 
         WMLResource._chk_and_block_create_update_for_python36(self)
         #Script._validate_type(name, u'name', str, True)
@@ -525,7 +528,7 @@ class Script(WMLResource):
 
             **Example**
 
-             >>> client.script.download(asset_uid,"script_file.zip")
+             >>> client.script.download(asset_uid,"script_file")
          """
         if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
@@ -564,7 +567,7 @@ class Script(WMLResource):
                 with open(filename, 'wb') as f:
                     f.write(downloaded_asset)
                 print(u'Successfully saved data asset content to file: \'{}\''.format(filename))
-                return os.getcwd() + "/" + filename
+                return os.path.abspath(filename)
             except IOError as e:
                 raise WMLClientError(u'Saving data asset with artifact_url: \'{}\'  to local file failed.'.format(filename), e)
         else:
@@ -597,7 +600,7 @@ class Script(WMLResource):
                     with open(filename, 'wb') as f:
                         f.write(downloaded_asset)
                     print(u'Successfully saved data asset content to file: \'{}\''.format(filename))
-                    return os.getcwd() + "/" + filename
+                    return os.path.abspath(filename)
                 except IOError as e:
                     raise WMLClientError(u'Saving asset with artifact_url to local file: \'{}\' failed.'.format(filename), e)
             else:
@@ -1037,7 +1040,7 @@ class Script(WMLResource):
                                                            limit,
                                                            'List Script revisions',
                                                            summary=None,
-                                                           pre_defined=None)[u'results']
+                                                           pre_defined=None)[u'resources']
         script_values = [
             (m[u'metadata'][u'asset_id'],
              m[u'metadata'][u'revision_id'],
@@ -1093,30 +1096,32 @@ class Script(WMLResource):
         #                                        summary=None,
         #                                        pre_defined=None,
         #                                        revision=rev_uid))
-
-        response = self._get_required_element_from_response(self._get_with_or_without_limit(url,
-                                               limit=None,
-                                               op_name="asset_revision",
-                                               summary=None,
-                                               pre_defined=None,
-                                               revision=rev_uid))
+        resources = self._get_with_or_without_limit(url,
+                                                    limit=None,
+                                                    op_name="asset_revision",
+                                                    summary=None,
+                                                    pre_defined=None,
+                                                    revision=rev_uid)['resources']
+        responses = [self._get_required_element_from_response(resource) for resource in resources]
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
-            return response
+            return responses
         else:
-            entity = response[u'entity']
+            final_responses = []
+            for response in responses:
+                entity = response[u'entity']
 
-            try:
-                del entity[u'script'][u'ml_version']
-            except KeyError:
-                pass
+                try:
+                    del entity[u'script'][u'ml_version']
+                except KeyError:
+                    pass
 
-            final_response = {
-                "metadata": response[u'metadata'],
-                "entity": entity
-            }
+                final_responses.append({
+                    "metadata": response[u'metadata'],
+                    "entity": entity
+                })
 
-            return final_response
+            return final_responses
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, asset_uid):
@@ -1233,4 +1238,4 @@ class Script(WMLResource):
                         new_el[u'metadata'].update({'href': href_without_host})
             return new_el
         except Exception as e:
-            raise WMLClientError("Failed to read Response from down-stream service: " + response_data.text)
+            raise WMLClientError(f"Failed to read Response from down-stream service: {response_data}")
