@@ -17,7 +17,7 @@ import requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import ShinyMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
-from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
+from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure, ForbiddenActionForGitBasedProject
 import os
 
 _DEFAULT_LIST_LENGTH = 50
@@ -111,6 +111,9 @@ class Shiny(WMLResource):
                  >>> }
                  >>> asset_details = client.shiny.store(meta_props,file_path="/path/to/file")
         """
+        if self._client.project_type == 'local_git_storage':
+            raise ForbiddenActionForGitBasedProject(reason="Storing Shiny apps is not supported for git based project.")
+
         WMLResource._chk_and_block_create_update_for_python36(self)
 
         Shiny._validate_type(file_path, u'file_path', str, True)
@@ -827,7 +830,7 @@ class Shiny(WMLResource):
                                                            limit,
                                                            'List Shiny revisions',
                                                            summary=None,
-                                                           pre_defined=None)[u'results']
+                                                           pre_defined=None)[u'resources']
         shiny_values = [
             (m[u'metadata'][u'asset_id'],
              m[u'metadata'][u'revision_id'],
@@ -874,23 +877,23 @@ class Shiny(WMLResource):
         #                                        summary=None,
         #                                        pre_defined=None,
         #                                        revision=rev_uid))
-
-        response = self._get_required_element_from_response(self._get_with_or_without_limit(url,
-                                               limit=None,
-                                               op_name="asset_revision",
-                                               summary=None,
-                                               pre_defined=None,
-                                               revision=rev_uid))
+        resources = self._get_with_or_without_limit(url,
+                                                    limit=None,
+                                                    op_name="asset_revision",
+                                                    summary=None,
+                                                    pre_defined=None,
+                                                    revision=rev_uid)['resources']
+        responses = [self._get_required_element_from_response(resource) for resource in resources]
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
-            return response
+            return responses
         else:
-            final_response = {
+            final_responses = [{
                 "metadata": response[u'metadata'],
                 "entity": {}
-            }
+            } for response in responses]
 
-            return final_response
+            return final_responses
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def _delete(self, asset_uid):
