@@ -17,7 +17,8 @@ from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_co
 from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, RunStateTypes
 
-from ibm_watson_machine_learning.tests.utils.assertions import get_and_predict_all_pipelines_as_lale
+from ibm_watson_machine_learning.tests.utils.assertions import get_and_predict_all_pipelines_as_lale, \
+    validate_autoai_experiment
 
 from ibm_watson_machine_learning.utils.autoai.utils import chose_model_output
 
@@ -138,7 +139,9 @@ class AbstractTestAutoAIAsync(abc.ABC):
         pass
 
     def test_03_initialize_optimizer(self):
-        AbstractTestAutoAIAsync.remote_auto_pipelines = self.experiment.optimizer(**self.experiment_info)
+        AbstractTestAutoAIAsync.experiment_info = validate_autoai_experiment(self.experiment_info, self.pod_version)
+
+        AbstractTestAutoAIAsync.remote_auto_pipelines = self.experiment.optimizer(**AbstractTestAutoAIAsync.experiment_info)
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
                               msg="experiment.optimizer did not return RemoteAutoPipelines object")
@@ -276,26 +279,6 @@ class AbstractTestAutoAIAsync(abc.ABC):
         print(predictions)
         self.assertGreater(len(predictions), 0, msg="Empty predictions")
 
-    def test_18_get_random_historical_optimizer_and_its_pipeline(self):
-        if not self.HISTORICAL_RUNS_CHECK:
-            self.skipTest("Skipping historical runs check.")
-
-        run_params = self.experiment.runs(filter=self.OPTIMIZER_NAME).get_params(run_id=self.prev_run_id)
-        self.assertIn('prediction_type', run_params,
-                      msg="prediction_type field not fount in run_params. Run_params are: {}".format(run_params))
-        historical_opt = self.experiment.runs.get_optimizer(self.prev_run_id)
-        self.assertIsInstance(historical_opt, RemoteAutoPipelines,
-                              msg="historical_optimizer is not type RemoteAutoPipelines. It's type of {}".format(
-                                  type(historical_opt)))
-
-        summary = historical_opt.summary()
-        self.assertGreater(len(summary), 0, msg=f"No pipelines found for optimizer with run_id = {self.prev_run_id},"
-                                                f" and parameters: {run_params}")
-
-        pipeline_name = summary.index.values[0]
-        pipeline = historical_opt.get_pipeline(pipeline_name, self.experiment.PipelineTypes.SKLEARN)
-        self.assertIsInstance(pipeline, Pipeline)
-
 
 class AbstractTestAutoAISync(abc.ABC):
     """
@@ -413,7 +396,9 @@ class AbstractTestAutoAISync(abc.ABC):
         pass
 
     def test_03_initialize_optimizer(self):
-        AbstractTestAutoAISync.remote_auto_pipelines = self.experiment.optimizer(**self.experiment_info)
+        AbstractTestAutoAISync.experiment_info = validate_autoai_experiment(self.experiment_info, self.pod_version)
+
+        AbstractTestAutoAISync.remote_auto_pipelines = self.experiment.optimizer(**AbstractTestAutoAISync.experiment_info)
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
                               msg="experiment.optimizer did not return RemoteAutoPipelines object")
