@@ -126,6 +126,7 @@ class AbstractTestAutoAIRemote(abc.ABC):
             autoai_pod_version=self.pod_version,
             notebooks=True,
             n_parallel_data_connections=self.max_connection_nb,
+            retrain_on_holdout=True
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -156,6 +157,14 @@ class AbstractTestAutoAIRemote(abc.ABC):
         AbstractTestAutoAIRemote.X_values = self.train_data.drop([self.prediction_column], axis=1)[:10].values
         AbstractTestAutoAIRemote.y_values = self.train_data[self.prediction_column][:10]
 
+    def test_06b_get_train_data(self):
+        train_data, holdout_data = self.remote_auto_pipelines.get_data_connections()[0].read(with_holdout_split=True)
+
+        print("train data sample:")
+        print(train_data)
+        print("holdout data sample:")
+        print(holdout_data)
+
     def test_07_get_run_status(self):
         status = self.remote_auto_pipelines.get_run_status()
         self.assertEqual(status, "completed", msg="AutoAI run didn't finished successfully. Status: {}".format(status))
