@@ -184,7 +184,7 @@ class TestAutoAIRemote(unittest.TestCase):
             text_processing=self.with_text_transformer,
             holdout_size=0.1,
             max_number_of_estimators=1,
-            # text_columns_names=self.text_columns,
+            text_columns_names=self.text_columns,
             autoai_pod_version=self.pod_version
         )
 
@@ -241,15 +241,14 @@ class TestAutoAIRemote(unittest.TestCase):
 
         str_feature_importance_index_list = str(list(feature_importance_df.sort_index().index))
 
-        # TODO: Uncomment when support text columns
-        # for column in self.text_columns:
-        #     self.assertIn(f'word2vec({column})', str_feature_importance_index_list,
-        #                   msg=f"word2vec({column}) is not in features importance table. Full table: {feature_importance_df}")
+        for column in self.text_columns:
+            self.assertIn(f'word2vec({column})', str_feature_importance_index_list,
+                          msg=f"word2vec({column}) is not in features importance table. Full table: {feature_importance_df}")
 
-        # self.assertIn('NewTextFeature_0', str_feature_importance_index_list,
-        #               msg="Text features were numerated incorrectly.")
-        # self.assertIn(f'NewTextFeature_{self.word2vec_feature_number*len(self.text_columns)-1}',
-        #               str_feature_importance_index_list, msg="Text features were numerated incorrectly.")
+        self.assertIn('NewTextFeature_0', str_feature_importance_index_list,
+                      msg="Text features were numerated incorrectly.")
+        self.assertIn(f'NewTextFeature_{self.word2vec_feature_number*len(self.text_columns)-1}',
+                      str_feature_importance_index_list, msg="Text features were numerated incorrectly.")
 
     def test_08b_get_metrics(self):
         self.wml_client.training.get_metrics(self.run_id)
