@@ -194,7 +194,7 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column=self.prediction_column,
             scoring=self.experiment.Metrics.ROOT_MEAN_SQUARED_ERROR,
             text_processing=self.with_text_transformer,
-            # text_columns_names=self.text_columns,
+            text_columns_names=self.text_columns,
             word2vec_feature_number=self.word2vec_feature_number,
             autoai_pod_version=self.pod_version
         )
@@ -248,16 +248,15 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(feature_importance_df)
         str_feature_importance_index_list = str(list(feature_importance_df.sort_index().index))
 
-        # TODO: Uncomment when support text columns
-        # for column in self.text_columns:
-        #     self.assertIn(f'word2vec({column})', str(str_feature_importance_index_list),
-        #                   msg=f"word2vec({column}) is not in features importance table."
-        #                       f" Full features list: {str_feature_importance_index_list}")
-        #
-        # self.assertIn('NewTextFeature_0',str_feature_importance_index_list,
-        #               msg="Text features were numerated incorrectly.")
-        # self.assertIn(f'NewTextFeature_{self.word2vec_feature_number*len(self.text_columns)-1}',
-        #               str_feature_importance_index_list, msg="Text features were numerated incorrectly.")
+        for column in self.text_columns:
+            self.assertIn(f'word2vec({column})', str(str_feature_importance_index_list),
+                          msg=f"word2vec({column}) is not in features importance table."
+                              f" Full features list: {str_feature_importance_index_list}")
+
+        self.assertIn('NewTextFeature_0',str_feature_importance_index_list,
+                      msg="Text features were numerated incorrectly.")
+        self.assertIn(f'NewTextFeature_{self.word2vec_feature_number*len(self.text_columns)-1}',
+                      str_feature_importance_index_list, msg="Text features were numerated incorrectly.")
 
     def test_08b_get_metrics(self):
         self.wml_client.training.get_metrics(self.run_id)
