@@ -129,7 +129,7 @@ def get_space_id(wml_client, space_name, cos_resource_instance_id=None):
     """
     Return space id of existed or just created space named as `space_name`.
     """
-    spaces_details = wml_client.spaces.get_details(limit=1000).get('resources')
+    spaces_details = wml_client.spaces.get_details(limit=200).get('resources')
     space_id = None
     for space_d in spaces_details:
         if space_d['entity']['name'] == space_name:
@@ -457,7 +457,7 @@ def setup_nfs_env(wml_credentials, dataset_file_name, remote_directory='datasets
     return connection_id, f"/{remote_directory}/{dataset_file_name}", asset_id
 
 
-def save_data_to_container(data_path, data_cos_path, wml_client):
+def save_data_to_container(data_path, data_cos_path, wml_client, data_filenames=None):
     import requests
 
     if wml_client.default_space_id:
@@ -493,11 +493,12 @@ def save_data_to_container(data_path, data_cos_path, wml_client):
                             secret_access_key=properties.get('secret_access_key'),
                             cos_endpoint=properties['endpoint_url'],
                             bucket_name=properties['bucket_name'],
+                            data_filenames=data_filenames,
                             is_container=True)
 
 
 def save_data_to_cos_bucket(data_path, data_cos_path, access_key_id, secret_access_key, cos_endpoint, bucket_name,
-                            is_container=False):
+                            data_filenames=None, is_container=False):
     cos_resource = ibm_boto3.resource(
         service_name="s3",
         endpoint_url=cos_endpoint,
@@ -513,17 +514,32 @@ def save_data_to_cos_bucket(data_path, data_cos_path, access_key_id, secret_acce
             assert bucket_exists(cos_resource, bucket_name)
 
     # Write data to cos bucket
-    cos_resource.Bucket(bucket_name).upload_file(data_path, data_cos_path)
+
+    if os.path.isfile(data_path):
+        cos_resource.Bucket(bucket_name).upload_file(data_path, data_cos_path)
+    elif os.path.isdir(data_path):
+        # upload multiple files
+        for file in data_filenames:
+            data_file_path = os.path.join(data_path, file) if data_path else file
+            cos_file_path = os.path.join(data_cos_path, file) if data_cos_path else file
+
+            cos_resource.Bucket(bucket_name).upload_file(data_file_path, cos_file_path)
+
+    else:
+        raise ValueError("data_path is not valid directory or file.")
 
     return bucket_name
 
 
 def create_connection_to_cos(wml_client, cos_credentials, cos_endpoint, bucket_name, save_data=False, data_path=None,
-                             data_cos_path=None):
+                             data_cos_path=None, data_filenames=None):
     if save_data and data_path and data_cos_path:
-        bucket_name = save_data_to_cos_bucket(data_path, data_cos_path, cos_credentials['cos_hmac_keys']['access_key_id'],
-                                cos_credentials['cos_hmac_keys']['secret_access_key'], cos_endpoint, bucket_name,
-                                is_container=False)
+        bucket_name = save_data_to_cos_bucket(data_path, data_cos_path,
+                                              cos_credentials['cos_hmac_keys']['access_key_id'],
+                                              cos_credentials['cos_hmac_keys']['secret_access_key'], cos_endpoint,
+                                              bucket_name,
+                                              data_filenames=data_filenames,
+                                              is_container=False)
 
     auth_endpoint = cos_credentials.get('auth_endpoint')
     if auth_endpoint is None:
