@@ -359,12 +359,6 @@ def load_file_from_file_system_nonautoai(wml_client: 'APIClient',
         File content
     """
     # note: prepare the file path
-
-    if wml_client.default_project_id:
-        file_path = f"{file_path}?project_id={wml_client.default_project_id}"
-
-    else:
-        file_path = f"{file_path}?space_id={wml_client.default_space_id}"
     # --- end note
 
     buffer = io.BytesIO()
@@ -372,6 +366,7 @@ def load_file_from_file_system_nonautoai(wml_client: 'APIClient',
     response_with_model = requests.get(
         url=f"{wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}{file_path}",
         headers=wml_client._get_headers(),
+        params=wml_client._params(),
         stream=stream,
         verify=False)
 
@@ -1146,12 +1141,12 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
                         or package['name'] == 'lale' or package['name'] == 'snapml':
                     if version.parse(installed_module_version) < version.parse(package['version']):
                         # we should produce different error for lale and snap_ml as only 2 major numbers are significant
-                        packages_less_strict_error_list = ['lale', 'snapml'],
+                        packages_less_strict_error_list = ['lale', 'snapml']
                         if package['name'] in packages_less_strict_error_list and len(
                                 package['version'].split('.')) >= 3:
-                            _version = package['version'].split('.')[:2]  # take only 3 major version number
-                            _version[-1] = 'x'
+                            _version = package['version'].split('.')[:3]  # take only 3 major version number
                             package['version'] = '.'.join(_version)
+                            package['version'] = f">={package['version']}"
 
                         errored_packages.append(package)
 
@@ -1581,7 +1576,7 @@ def validate_additional_params_for_optimizer(params):
         '_enable_snapml_estimators', 'return_holdout_indices', 'retrain_pipelines_on_holdout_data',
         'retrain_on_holdout',
         'sampling_type', 'n_parallel_data_connections', 'calculate_data_metrics',
-        'batch_size', 'metrics_on_logical_batch', 'logical_batch_size', 'text_columns_names'
+        'batch_size', 'metrics_on_logical_batch', 'logical_batch_size', 'text_columns_names', 'enable_all_data_sources'
     ]
 
     for k in params:
@@ -1742,8 +1737,11 @@ def validate_optimizer_enum_values(
         is_list_composed_from_enum(sequence, enum_class)
 
     # Note: scoring can be None or have one of values from Metrics enum.
+    # Note: allow pass fairness scoring values: TODO: Remove when official fairness support will be available
+    additional_allowed_scoring_values = ['r2_and_disparate_impact', 'accuracy_and_disparate_impact']
     if scoring is not None:
-        is_list_composed_from_enum([scoring], Metrics)
+        if scoring not in additional_allowed_scoring_values:
+            is_list_composed_from_enum([scoring], Metrics)
 
 
 def fallback_to_pip_for_version_check(package: dict) -> str:
