@@ -214,7 +214,7 @@ class WSConnection(FLConnection):
 
                         # check if error
                         if recv_msg.message_type == MessageType.ERROR_AUTH.value :
-                            logger.info("PartyRecvLoop : Auth Error. Please verify training ID, RTS, project permission and token")
+                            logger.info("PartyRecvLoop : Auth Error. Please verify training ID, RTS, allowed identities, project permission and token")
                             self.stop()
                             break
 
