@@ -20,6 +20,7 @@ from ibmfl.util import fl_metrics
 from ibmfl.model.fl_model import FLModel
 from ibmfl.model.model_update import ModelUpdate
 from ibmfl.exceptions import FLException, LocalTrainingException, ModelException
+from tensorflow.keras import backend as K
 
 logger = logging.getLogger(__name__)
 
@@ -73,7 +74,7 @@ class TensorFlowFLModel(FLModel):
         self.is_classification = True if not (model_spec and model_spec.get(
             'is_classification')) else model_spec.get('is_classification')
 
-    def fit_model(self, train_data, fit_params=None, **kwargs):
+    def fit_model(self, train_data, fit_params=None, validation_data=None, **kwargs):
         """
         Fits current model with provided training data.
 
@@ -90,6 +91,8 @@ class TensorFlowFLModel(FLModel):
         :return: None
         """
         fit_args = self.get_fit_args(fit_params, **kwargs)
+        if validation_data is not None:
+            fit_args['validation_data'] = validation_data
 
         logger.info('Training hps for this round => '
                     'batch_size: {}, epochs {}, steps_per_epoch {}'
@@ -609,6 +612,13 @@ class TensorFlowFLModel(FLModel):
         hyperparams = global_params.get('hyperparams', {}) or {} if global_params else {}
         local_hp = hyperparams.get('local', {}) or {}
         training_hp = local_hp.get('training', {}) or {}
+        optimizer_hp = local_hp.get('optimizer', {}) or {}
+
+        lr = optimizer_hp.get('lr', None)
+        if lr:
+            K.set_value(self.model.optimizer.learning_rate, lr)
+        logger.info("Learning rate of optimizer is set as {}".format(
+            self.model.optimizer.learning_rate))
 
         fit_args['batch_size'] = training_hp.get('batch_size', self.batch_size)
         if 'batch_size' in local_params:
