@@ -370,7 +370,7 @@ def get_lt_from_config(config):
 
 
 def get_mh_from_config(config):
-    """ Load data class information from params provided in config file
+    """ Load metrics handler class information from params provided in config file
     :param config: dictionary of configuration
     :type config: `dict`
     :return: dictionary of class references
@@ -390,7 +390,7 @@ def get_mh_from_config(config):
                 'Error occurred while loading mh config.')
 
     else:
-        logger.info('No data config provided for this setup.')
+        logger.info('No metrics config provided for this setup.')
     return mh_config
 
 
@@ -415,7 +415,7 @@ def get_mrec_from_config(config):
         except InvalidConfigurationException as ex:
             logger.exception(ex)
             raise InvalidConfigurationException(
-                'Error occured while loading data config.')
+                'Error occurred while loading data config.')
 
     else:
         logger.info('No metrics recorder config provided for this setup.')
